==> uber_affiliate-1.0.0-alpha1.tar.gz: uber_affiliate/src/Form/AdminContentForm.php <==
<?php

namespace Drupal\uber_affiliate\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Admin Content Form.
 */
class AdminContentForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'uber_affiliate.admin.content.settings';

  /**
   * Required by FormBase.
   */
  public function getFormId() {
    return 'uber_affiliate_admin_content_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * PayoutForm.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // @TODO change to dynamic.
    $node_types = ['page', 'article'];
    $allow_all_options = array(0 => t('No'), 1 => t('Yes'));
    $form['affiliate_module_affiliate_menu_path'] = array(
      '#type' => 'textfield',
      '#title' => t('Click-thru menu path'),
      '#default_value' => \Drupal::state()->get('affiliate_module_affiliate_menu_path', 'affiliate'),
      '#description' => t('Many pieces of (good) software exist that will essentially block anything from being displayed inside a browser if the thing being viewed comes from a link that contains words like <em>affiliate</em>, <em>click</em>, <em>partner</em>, <em>ad</em>, etc. This setting allows the menu paths for affiliate click-thru links to be set to something other than the word <em>affiliate</em>.'),
      '#required' => TRUE,
    );
    $form['affiliate_module_allow_all_paths'] = array(
      '#type' => 'radios',
      '#title' => t('Allow all paths'),
      '#default_value' => \Drupal::state()->get('affiliate_module_allow_all_paths', 0),
      '#options' => $allow_all_options,
      '#description' => t('Select whether affiliates will be credited for referring anyone to any URL from this site (i.e. if an affiliate refers someone to the contact page, they will receive credit for that).'),
    );
    $form['affiliate_module_allow_all_node_types'] = array(
      '#type' => 'radios',
      '#title' => t('Allow all content types'),
      '#default_value' => \Drupal::state()->get('affiliate_module_allow_all_node_types', 0),
      '#options' => $allow_all_options,
      '#description' => t('Select whether affiliates will be credited for referring anyone to any piece of content, regardless of its type. Note: a "piece of content", in this case and most others, is a node (i.e. the contact page, any custom views, etc, are not nodes).'),
      '#states' => array(
        'invisible' => array(
          ':input[name="affiliate_module_allow_all_paths"]' => array('value' => 1),
        ),
      ),
    );
    $form['affiliate_module_allowed_node_types'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Allowed content types'),
      '#default_value' => \Drupal::state()->get('affiliate_module_allowed_node_types', array()),
      '#options' => $node_types,
      '#description' => t('Select which content types should be automatically available to all affiliates. Each new node will be available when cron is run.'),
      '#states' => array(
        'visible' => array(
          ':input[name="affiliate_module_allow_all_paths"]' => array('value' => 0),
          ':input[name="affiliate_module_allow_all_node_types"]' => array('value' => 0),
        ),
      ),
    );
    $form['affiliate_module_affiliate_link_text'] = array(
      '#type' => 'textfield',
      '#title' => t('Instructional text'),
      '#default_value' => \Drupal::state()->get('affiliate_module_affiliate_link_text', t('Copy the code below and paste it into your website')),
      '#description' => t('Text instructing users to copy the text in the affiliate link box and paste it into their website in order to earn affiliate credit.'),
    );
    $form['affiliate_module_flush_all_caches_on_admin_content_form_submit'] = array(
      '#type' => 'radios',
      '#title' => t('Flush all caches and rebuild menus after submitting this form'),
      '#default_value' => 0,
      '#options' => array(0 => t('No'), 1 => t('Yes')),
      '#description' => t('If you changed the click-thru menu path above, it is highly advised that you flush all the caches and rebuild all the menus after submitting this form. Otherwise there is a very good chance that your affiliate links will break because the system will not know that the click-thru menu path has changed.'),
      '#required' => TRUE,
    );

    return $form;

  }


  /**
   * Required by FormBase.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $menu_path_submitted = $form_state['values']['affiliate_module_affiliate_menu_path'];
    $menu_path_current = \Drupal::state()->get('affiliate_module_affiliate_menu_path', 'affiliate');
    $menu_path_is_dir_or_file = (is_dir(DRUPAL_ROOT . '/' . $menu_path_submitted) || file_exists(DRUPAL_ROOT . '/' . $menu_path_submitted)) ? TRUE : FALSE;
    $pattern = '~^([a-zA-Z0-9_-]+)$~';
    // Remove? Change?
    if (!preg_match($pattern, $menu_path_submitted)) {
      form_set_error('affiliate_module_affiliate_menu_path', t('The affiliate menu path must only contain alphanumeric characters, underscores, and/or dashes.'));
    }
    // Make sure the submitted path does not already exist
    if (drupal_valid_path($menu_path_submitted) && $menu_path_submitted != $menu_path_current) {
      form_set_error('affiliate_module_affiliate_menu_path', t('This path already exists and cannot be used as the affiliate menu path. Please choose a different path.'));
    }
    if ($menu_path_is_dir_or_file) {
      form_set_error('affiliate_module_affiliate_menu_path', t('This path cannot be used as the affiliate menu path because there is either a directory or a file that exists on your server with the same name. Please choose a different path.'));
    }
  }

  /**
   * Required by FormBase.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $menu_path_submitted = $form_state['values']['affiliate_module_affiliate_menu_path'];
    $menu_path_current = \Drupal::state()->get('affiliate_module_affiliate_menu_path', 'affiliate');
    $rebuild_caches = (int) $form_state['values']['affiliate_module_flush_all_caches_on_admin_content_form_submit'];
    if ($rebuild_caches) {
      drupal_flush_all_caches();
      drupal_set_message(t('All caches have been cleared and the menu router has been rebuilt to reflect your updated affiliate menu path.'));
    }
    // Remind the admin to rebuild the site's menus if the affiliate menu path has changed.
    else if ($menu_path_submitted != $menu_path_current) {
      drupal_set_message(t('The click-thru menu path appears to have changed, but no caches have been flushed and the menu router has not been updated. If you encounter "Page not found" errors, please consider re-submitting this form but selecting <em>Yes</em> under the <em>Flush all caches</em> option. Doing so will help to ensure that any stale data is removed from the database.'), 'warning');
    }
    else if (!drupal_valid_path($menu_path_submitted)) {
      drupal_set_message(t('Warning: it appears as though your site requires its caches to be flushed and its menu router to be updated. Until such time, your affiliates will likely encounter "Page not found" errors due to stale information inside the database. To remove the stale information, please consider re-submitting this form but selecting <em>Yes</em> under the <em>Flush all caches</em> option.'), 'warning');
    }
  }

}

==> uber_affiliate-2.0.0-alpha1.tar.gz: uber_affiliate/src/Form/AdminContentForm.php <==
<?php

namespace Drupal\uber_affiliate\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Admin Content Form.
 */
class AdminContentForm extends ConfigFormBase {

  /**
   * Config settings.
   *
   * @var string
   */
  const SETTINGS = 'uber_affiliate.admin.content.settings';

  /**
   * Required by FormBase.
   */
  public function getFormId() {
    return 'uber_affiliate_admin_content_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      static::SETTINGS,
    ];
  }

  /**
   * PayoutForm.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // @TODO change to dynamic.
    $node_types = ['page', 'article'];
    $allow_all_options = array(0 => t('No'), 1 => t('Yes'));
    $form['affiliate_module_affiliate_menu_path'] = array(
      '#type' => 'textfield',
      '#title' => t('Click-thru menu path'),
      '#default_value' => \Drupal::state()->get('affiliate_module_affiliate_menu_path', 'affiliate'),
      '#description' => t('Many pieces of (good) software exist that will essentially block anything from being displayed inside a browser if the thing being viewed comes from a link that contains words like <em>affiliate</em>, <em>click</em>, <em>partner</em>, <em>ad</em>, etc. This setting allows the menu paths for affiliate click-thru links to be set to something other than the word <em>affiliate</em>.'),
      '#required' => TRUE,
    );
    $form['affiliate_module_allow_all_paths'] = array(
      '#type' => 'radios',
      '#title' => t('Allow all paths'),
      '#default_value' => \Drupal::state()->get('affiliate_module_allow_all_paths', 0),
      '#options' => $allow_all_options,
      '#description' => t('Select whether affiliates will be credited for referring anyone to any URL from this site (i.e. if an affiliate refers someone to the contact page, they will receive credit for that).'),
    );
    $form['affiliate_module_allow_all_node_types'] = array(
      '#type' => 'radios',
      '#title' => t('Allow all content types'),
      '#default_value' => \Drupal::state()->get('affiliate_module_allow_all_node_types', 0),
      '#options' => $allow_all_options,
      '#description' => t('Select whether affiliates will be credited for referring anyone to any piece of content, regardless of its type. Note: a "piece of content", in this case and most others, is a node (i.e. the contact page, any custom views, etc, are not nodes).'),
      '#states' => array(
        'invisible' => array(
          ':input[name="affiliate_module_allow_all_paths"]' => array('value' => 1),
        ),
      ),
    );
    $form['affiliate_module_allowed_node_types'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Allowed content types'),
      '#default_value' => \Drupal::state()->get('affiliate_module_allowed_node_types', array()),
      '#options' => $node_types,
      '#description' => t('Select which content types should be automatically available to all affiliates. Each new node will be available when cron is run.'),
      '#states' => array(
        'visible' => array(
          ':input[name="affiliate_module_allow_all_paths"]' => array('value' => 0),
          ':input[name="affiliate_module_allow_all_node_types"]' => array('value' => 0),
        ),
      ),
    );
    $form['affiliate_module_affiliate_link_text'] = array(
      '#type' => 'textfield',
      '#title' => t('Instructional text'),
      '#default_value' => \Drupal::state()->get('affiliate_module_affiliate_link_text', t('Copy the code below and paste it into your website')),
      '#description' => t('Text instructing users to copy the text in the affiliate link box and paste it into their website in order to earn affiliate credit.'),
    );
    $form['affiliate_module_flush_all_caches_on_admin_content_form_submit'] = array(
      '#type' => 'radios',
      '#title' => t('Flush all caches and rebuild menus after submitting this form'),
      '#default_value' => 0,
      '#options' => array(0 => t('No'), 1 => t('Yes')),
      '#description' => t('If you changed the click-thru menu path above, it is highly advised that you flush all the caches and rebuild all the menus after submitting this form. Otherwise there is a very good chance that your affiliate links will break because the system will not know that the click-thru menu path has changed.'),
      '#required' => TRUE,
    );

    return $form;

  }


  /**
   * Required by FormBase.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $menu_path_submitted = $form_state['values']['affiliate_module_affiliate_menu_path'];
    $menu_path_current = \Drupal::state()->get('affiliate_module_affiliate_menu_path', 'affiliate');
    $menu_path_is_dir_or_file = (is_dir(DRUPAL_ROOT . '/' . $menu_path_submitted) || file_exists(DRUPAL_ROOT . '/' . $menu_path_submitted)) ? TRUE : FALSE;
    $pattern = '~^([a-zA-Z0-9_-]+)$~';
    // Remove? Change?
    if (!preg_match($pattern, $menu_path_submitted)) {
      form_set_error('affiliate_module_affiliate_menu_path', t('The affiliate menu path must only contain alphanumeric characters, underscores, and/or dashes.'));
    }
    // Make sure the submitted path does not already exist
    if (drupal_valid_path($menu_path_submitted) && $menu_path_submitted != $menu_path_current) {
      form_set_error('affiliate_module_affiliate_menu_path', t('This path already exists and cannot be used as the affiliate menu path. Please choose a different path.'));
    }
    if ($menu_path_is_dir_or_file) {
      form_set_error('affiliate_module_affiliate_menu_path', t('This path cannot be used as the affiliate menu path because there is either a directory or a file that exists on your server with the same name. Please choose a different path.'));
    }
  }

  /**
   * Required by FormBase.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $menu_path_submitted = $form_state['values']['affiliate_module_affiliate_menu_path'];
    $menu_path_current = \Drupal::state()->get('affiliate_module_affiliate_menu_path', 'affiliate');
    $rebuild_caches = (int) $form_state['values']['affiliate_module_flush_all_caches_on_admin_content_form_submit'];
    if ($rebuild_caches) {
      drupal_flush_all_caches();
      $this->messenger()->addStatus(t('All caches have been cleared and the menu router has been rebuilt to reflect your updated affiliate menu path.'));
    }
    // Remind the admin to rebuild the site's menus if the affiliate menu path has changed.
    else if ($menu_path_submitted != $menu_path_current) {
      $this->messenger()->addWarning(t('The click-thru menu path appears to have changed, but no caches have been flushed and the menu router has not been updated. If you encounter "Page not found" errors, please consider re-submitting this form but selecting <em>Yes</em> under the <em>Flush all caches</em> option. Doing so will help to ensure that any stale data is removed from the database.'));
    }
    else if (!drupal_valid_path($menu_path_submitted)) {
      $this->messenger()->addWarning(t('Warning: it appears as though your site requires its caches to be flushed and its menu router to be updated. Until such time, your affiliates will likely encounter "Page not found" errors due to stale information inside the database. To remove the stale information, please consider re-submitting this form but selecting <em>Yes</em> under the <em>Flush all caches</em> option.'));
    }
  }

}
